==> magic3_1.8.0_b9_src.tar.gz: magic3/widgets/banner2/include/container/admin_banner2BaseWidgetContainer.php <==
<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_banner2BaseWidgetContainer.php 1494 2009-02-02 10:59:58Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');

class admin_banner2BaseWidgetContainer extends BaseWidgetContainer
{
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @return								なし
	 */
	function _postAssign($request, &$param)
	{
		// ウィンドウオープンタイプ取得
		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
		if (!empty($openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $openBy);
				
		// 表示画面を決定
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		if (empty($task)) $task = 'banner';		// デフォルト画面を設定
		
		// パンくずリストを作成
		$createList = true;		// パンくずリストを作成するかどうか
		switch ($task){
			case 'banner':		// バナー管理
			case 'banner_list':		// バナー一覧管理
				$linkList = ' &gt;&gt; バナー管理';// パンくずリスト
				break;
			case 'image':		// 画像管理
			case 'image_detail':	// 画像詳細
				$linkList = ' &gt;&gt; 画像リンク管理';// パンくずリスト
				break;
			case 'image_select':	// 画像選択
				$createList = false;		// パンくずリストを作成するかどうか
				break;
		}

		if ($createList){				// パンくずリストを作成するとき
			// ####### 上段メニューの作成 #######
			$menuText = '<div id="configmenu-upper">' . M3_NL;
			$menuText .= '<ul>' . M3_NL;
		
			$current = '';
			$baseUrl = $this->getAdminUrlWithOptionParam(true);// 画面定義ID付き
		
			// バナー管理
			$current = '';
			$link = $baseUrl . '&task=banner';
			if ($task == 'banner' ||
				$task == 'banner_list'){
				$current = 'id="current"';
			}
			$menuText .= '<li ' . $current . '><a href="'. $this->convertUrlToHtmlEntity($link) .'"><span>バナー管理</span></a></li>' . M3_NL;
		
			// 画像管理
			$current = '';
			$link = $baseUrl . '&task=image';
			if ($task == 'image' ||		// 画像管理
				$task == 'image_detail'){		// 画像詳細
				$current = 'id="current"';
			}
			$menuText .= '<li ' . $current . '><a href="'. $this->convertUrlToHtmlEntity($link) .'"><span>画像リンク管理</span></a></li>' . M3_NL;
		
			// 上段メニュー終了
			$menuText .= '</ul>' . M3_NL;
			$menuText .= '</div>' . M3_NL;
		
			// 作成データの埋め込み
			$linkList = '<div id="configmenu-top"><label>' . 'バナー' . $linkList . '</div>';
			$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
			$this->tmpl->addVar("_widget", "menu_items", $outputText);
		} else {
			$this->tmpl->addVar("_widget", "menu_items", '');
		}
	}
}
?>

==> magic3_2.0.5_src.tar.gz: magic3/widgets/banner2/include/container/admin_banner2BaseWidgetContainer.php <==
<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_banner2BaseWidgetContainer.php 2248 2009-08-24 05:22:21Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');

class admin_banner2BaseWidgetContainer extends BaseAdminWidgetContainer
{
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @return								なし
	 */
	function _postAssign($request, &$param)
	{
		// ウィンドウオープンタイプ取得
		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
		if (!empty($openBy)) $this->addOptionUrlParam(M3_REQUEST_PARAM_OPEN_BY, $openBy);
				
		// 表示画面を決定
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		if (empty($task)) $task = 'banner';		// デフォルト画面を設定
		
		// パンくずリストを作成
		$createList = true;		// パンくずリストを作成するかどうか
		switch ($task){
			case 'banner':		// バナー管理
			case 'banner_list':		// バナー一覧管理
				$linkList = ' &gt;&gt; バナー管理';// パンくずリスト
				break;
			case 'image':		// 画像管理
			case 'image_detail':	// 画像詳細
				$linkList = ' &gt;&gt; 画像リンク管理';// パンくずリスト
				break;
			case 'image_select':	// 画像選択
				$createList = false;		// パンくずリストを作成するかどうか
				break;
		}

		if ($createList){				// パンくずリストを作成するとき
			// ####### 上段メニューの作成 #######
			$menuText = '<div id="configmenu-upper">' . M3_NL;
			$menuText .= '<ul>' . M3_NL;
		
			$current = '';
			$baseUrl = $this->getAdminUrlWithOptionParam(true);// 画面定義ID付き
		
			// バナー管理
			$current = '';
			$link = $this->getUrl($baseUrl . '&task=banner');
			if ($task == 'banner' ||
				$task == 'banner_list'){
				$current = 'id="current"';
			}
			$menuText .= '<li ' . $current . '><a href="'. $this->convertUrlToHtmlEntity($link) .'"><span>バナー管理</span></a></li>' . M3_NL;
		
			// 画像管理
			$current = '';
			$link = $this->getUrl($baseUrl . '&task=image');
			if ($task == 'image' ||		// 画像管理
				$task == 'image_detail'){		// 画像詳細
				$current = 'id="current"';
			}
			$menuText .= '<li ' . $current . '><a href="'. $this->convertUrlToHtmlEntity($link) .'"><span>画像リンク管理</span></a></li>' . M3_NL;
		
			// 上段メニュー終了
			$menuText .= '</ul>' . M3_NL;
			$menuText .= '</div>' . M3_NL;
		
			// 作成データの埋め込み
			$linkList = '<div id="configmenu-top"><label>' . 'バナー' . $linkList . '</div>';
			$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
			$this->tmpl->addVar("_widget", "menu_items", $outputText);
		} else {
			$this->tmpl->addVar("_widget", "menu_items", '');
		}
	}
}
?>
